#ifndef DIAGRAM__H_
#define DIAGRAM__H_

/**
  * @file DIAGRAM.h
  *
  * Library to draw bar and pie charts in Bitmaps.
  *
  * @author Marcell Dietl, Sven Eric Panitz
  * @date 25.01.2010
  *
  **/

/**
  * Fill the background of a Bitmap with a given color.
  *
  * The function depends on the fillRect() function to
  * draw a rectangle, starting from the bottom left of the
  * Bitmap to the upper right.
  *
  * @param this Pointer to the Bitmap in memory.
  * @param c Color to be used for the background.
  *
  **/
void background(Bmp* this, Color c);

/**
  * Draw a rectangle with a given color.
  *
  * The function draws a rectangle - starting from point x/y
  * with the width w and the height h.
  *
  * @param this Pointer to the Bitmap in memory.
  * @param c Color to be used for the rectangle's background.
  * @param x Starting point on the X-axis.
  * @param y Starting point on the Y-axis.
  * @param w Width of the rectangle.
  * @param h Height of the rectangle.
  *
  **/
void fillRect(Bmp* this, Color c, int x, int y, int w, int h);

/* Copied from skript.pdf ************************************************/

/**
  * Swap the values of two integers in memory.
  *
  * The function is only used by the drawLine() function to swap
  * the value saved in x with the one in y by simply manipulating the
  * memory pointers.
  *
  * @param x The value to be saved in y afterward.
  * @param y The value to be saved in x afterward.
  *
  **/
void swapValues(int* x, int* y);

/**
  * Draw a thin line from one point to another.
  *
  * The function draws a line with a given color from the point fromX/fromY
  * to the point toX/toY  - allowing any possible coordinates.
  *
  * @param this Pointer to the Bitmap in memory.
  * @param c Color to be used for the drawn line.
  * @param fromX Starting point on the X-axis.
  * @param fromY Starting point on the Y-axis.
  * @param toX End point on the X-axis.
  * @param toY End point on the Y-axis.
  *
  **/
void drawLine(Bmp* this, Color c, int fromX, int fromY, int toX, int toY);

/*************************************************************************/

/**
  * Draw a circle with a given color.
  *
  * The function draws a circle - starting from point x/y with
  * the given radius and color.
  *
  * @param this Pointer to the Bitmap in memory.
  * @param c Color to be used for the circle's background.
  * @param x Center point on the X-axis.
  * @param y Center point on the Y-axis.
  * @param radius Radius of the circle.
  *
  **/
void fillCircle(Bmp* this, Color c, int x, int y, int radius);

/**
  * Generate a Bitmap showing values as a bar chart.
  *
  * The function gets an array of double values as input and
  * generates a bar chart dynamically. Thus the user can simply
  * enter every possible array.
  *
  * @param values[] The array containing the bar chart's values.
  * @param valueLength The length of the array.
  *
  * @result Pointer to the generated Bitmap in memory.
  *
  **/
Bmp* barChart(double values[], int valueLength);

/**
  * Generate a Bitmap showing values as a pie chart.
  *
  * The function gets an array of double values as input and
  * generates a pie chart dynamically. Thus the user can simple
  * enter every possible array.
  *
  * @param values[] The array containing the pie chart's values.
  * @param valueLength The length of the array.
  *
  * @result Pointer to the generated Bitmap in memory.
  *
  **/
Bmp* pieChart(double values[], int valueLength);

#endif
